@@ -30,8 +30,9 @@ else:
 kivy.require('1.11.1')
 Config.set('input', 'mouse', 'mouse,multitouch_on_demand')
 kivy.resources.resource_add_path(os.path.join(os.path.dirname(__file__), 'resources'))
-pytesseract.pytesseract.tesseract_cmd = r'../pytesseract/tesseract'
 
+if platform.system() == 'Windows':
+    pytesseract.pytesseract.tesseract_cmd = r'../pytesseract/tesseract'
 
 # ---------------------------------- Screen Classes ---------------------------------- #
 
@@ -886,7 +887,7 @@ class BadApplesApp(App):
 
 
 def main():
-    if platform.system != 'Windows':
+    if platform.system() != 'Windows':
         os.system("sudo apt-get install xclip xsel")
         os.system("sudo apt install tesseract-ocr")
         os.system("sudo apt-get remove gstreamer1.0-alsa gstreamer1.0-libav gstreamer1.0-plugins-bad gstreamer1.0-plugins-base gstreamer1.0-plugins-good gstreamer1.0-plugins-ugly gstreamer1.0-pulseaudio libgstreamer-plugins-bad1.0-0 libgstreamer-plugins-base1.0-0 libgstreamer-plugins-good1.0-0 libgstreamer1.0-0")
